# Publisher plugins

-----

::: hatch.publish.plugin.interface.PublisherInterface
    options:
      members:
      - PLUGIN_NAME
      - app
      - root
      - cache_dir
      - project_config
      - plugin_config
      - disable
      - publish
